# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'admin.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import exchange_pb2 as exchange__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61\x64min.proto\x12\x05\x61\x64min\x1a\x0e\x65xchange.proto\"o\n AddAccountTypeToPartitionRequest\x12\x11\n\tpartition\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_type\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"L\n\x13\x45ndPartitionRequest\x12\x11\n\tpartition\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"N\n\x15PausePartitionRequest\x12\x11\n\tpartition\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"N\n\x15StartPartitionRequest\x12\x11\n\tpartition\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"+\n\nSettlement\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\t\"y\n\x16SettlePartitionRequest\x12\x11\n\tpartition\x18\x01 \x01(\t\x12(\n\rsettle_prices\x18\x02 \x03(\x0b\x32\x11.admin.Settlement\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"9\n\x13OpenExchangeRequest\x12\"\n\x04\x61uth\x18\x01 \x01(\x0b\x32\x14.admin.AdminAuthInfo\":\n\x14\x43loseExchangeRequest\x12\"\n\x04\x61uth\x18\x01 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"c\n\x10\x41\x64\x64SymbolRequest\x12\x11\n\tpartition\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\"\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"h\n\x12SetPositionRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\"\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"k\n\x15\x41\x64justPositionRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\"\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"X\n\x14SetAccountFeeRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0b\n\x03\x66\x65\x65\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"Y\n\x13SetEnableFeeRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"\x89\x01\n\x18SetPositionLimitsRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x13\n\x0blower_bound\x18\x03 \x01(\t\x12\x13\n\x0bupper_bound\x18\x04 \x01(\t\x12\"\n\x04\x61uth\x18\x05 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"R\n\x1bRegisterNamedAccountRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"P\n\x19RegisterBotAccountRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"L\n\x13\x41\x64\x64PartitionRequest\x12\x11\n\tpartition\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"1\n\rAdminAuthInfo\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\"a\n\x19SendPrivateMessageRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"b\n\x18SendPublicMessageRequest\x12\x11\n\tpartition\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"Y\n\x12GetPositionRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"E\n\x11UpsertUserRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"\\\n\x17\x41\x64\x64UserToAccountRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"L\n\x18\x43learUserAccountsRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.admin.AdminAuthInfo\"a\n\x1c\x44\x65leteUserFromAccountRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.admin.AdminAuthInfo2\xf1\r\n\x0c\x41\x64minService\x12_\n\x19\x41\x64\x64\x41\x63\x63ountTypeToPartition\x12\'.admin.AddAccountTypeToPartitionRequest\x1a\x19.exchange.GenericResponse\x12\x45\n\x0c\x45ndPartition\x12\x1a.admin.EndPartitionRequest\x1a\x19.exchange.GenericResponse\x12I\n\x0ePausePartition\x12\x1c.admin.PausePartitionRequest\x1a\x19.exchange.GenericResponse\x12I\n\x0eStartPartition\x12\x1c.admin.StartPartitionRequest\x1a\x19.exchange.GenericResponse\x12K\n\x0fSettlePartition\x12\x1d.admin.SettlePartitionRequest\x1a\x19.exchange.GenericResponse\x12\x45\n\x0cOpenExchange\x12\x1a.admin.OpenExchangeRequest\x1a\x19.exchange.GenericResponse\x12G\n\rCloseExchange\x12\x1b.admin.CloseExchangeRequest\x1a\x19.exchange.GenericResponse\x12?\n\tAddSymbol\x12\x17.admin.AddSymbolRequest\x1a\x19.exchange.GenericResponse\x12\x43\n\x0bSetPosition\x12\x19.admin.SetPositionRequest\x1a\x19.exchange.GenericResponse\x12I\n\x0e\x41\x64justPosition\x12\x1c.admin.AdjustPositionRequest\x1a\x19.exchange.GenericResponse\x12G\n\rSetAccountFee\x12\x1b.admin.SetAccountFeeRequest\x1a\x19.exchange.GenericResponse\x12\x45\n\x0cSetEnableFee\x12\x1a.admin.SetEnableFeeRequest\x1a\x19.exchange.GenericResponse\x12O\n\x11SetPositionLimits\x12\x1f.admin.SetPositionLimitsRequest\x1a\x19.exchange.GenericResponse\x12U\n\x14RegisterNamedAccount\x12\".admin.RegisterNamedAccountRequest\x1a\x19.exchange.GenericResponse\x12Q\n\x12RegisterBotAccount\x12 .admin.RegisterBotAccountRequest\x1a\x19.exchange.GenericResponse\x12\x45\n\x0c\x41\x64\x64Partition\x12\x1a.admin.AddPartitionRequest\x1a\x19.exchange.GenericResponse\x12Q\n\x12SendPrivateMessage\x12 .admin.SendPrivateMessageRequest\x1a\x19.exchange.GenericResponse\x12O\n\x11SendPublicMessage\x12\x1f.admin.SendPublicMessageRequest\x1a\x19.exchange.GenericResponse\x12\x43\n\x0bGetPosition\x12\x19.admin.GetPositionRequest\x1a\x19.exchange.GenericResponse\x12\x41\n\nUpsertUser\x12\x18.admin.UpsertUserRequest\x1a\x19.exchange.GenericResponse\x12M\n\x10\x41\x64\x64UserToAccount\x12\x1e.admin.AddUserToAccountRequest\x1a\x19.exchange.GenericResponse\x12O\n\x11\x43learUserAccounts\x12\x1f.admin.ClearUserAccountsRequest\x1a\x19.exchange.GenericResponse\x12W\n\x15\x44\x65leteUserFromAccount\x12#.admin.DeleteUserFromAccountRequest\x1a\x19.exchange.GenericResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ADDACCOUNTTYPETOPARTITIONREQUEST']._serialized_start=38
  _globals['_ADDACCOUNTTYPETOPARTITIONREQUEST']._serialized_end=149
  _globals['_ENDPARTITIONREQUEST']._serialized_start=151
  _globals['_ENDPARTITIONREQUEST']._serialized_end=227
  _globals['_PAUSEPARTITIONREQUEST']._serialized_start=229
  _globals['_PAUSEPARTITIONREQUEST']._serialized_end=307
  _globals['_STARTPARTITIONREQUEST']._serialized_start=309
  _globals['_STARTPARTITIONREQUEST']._serialized_end=387
  _globals['_SETTLEMENT']._serialized_start=389
  _globals['_SETTLEMENT']._serialized_end=432
  _globals['_SETTLEPARTITIONREQUEST']._serialized_start=434
  _globals['_SETTLEPARTITIONREQUEST']._serialized_end=555
  _globals['_OPENEXCHANGEREQUEST']._serialized_start=557
  _globals['_OPENEXCHANGEREQUEST']._serialized_end=614
  _globals['_CLOSEEXCHANGEREQUEST']._serialized_start=616
  _globals['_CLOSEEXCHANGEREQUEST']._serialized_end=674
  _globals['_ADDSYMBOLREQUEST']._serialized_start=676
  _globals['_ADDSYMBOLREQUEST']._serialized_end=775
  _globals['_SETPOSITIONREQUEST']._serialized_start=777
  _globals['_SETPOSITIONREQUEST']._serialized_end=881
  _globals['_ADJUSTPOSITIONREQUEST']._serialized_start=883
  _globals['_ADJUSTPOSITIONREQUEST']._serialized_end=990
  _globals['_SETACCOUNTFEEREQUEST']._serialized_start=992
  _globals['_SETACCOUNTFEEREQUEST']._serialized_end=1080
  _globals['_SETENABLEFEEREQUEST']._serialized_start=1082
  _globals['_SETENABLEFEEREQUEST']._serialized_end=1171
  _globals['_SETPOSITIONLIMITSREQUEST']._serialized_start=1174
  _globals['_SETPOSITIONLIMITSREQUEST']._serialized_end=1311
  _globals['_REGISTERNAMEDACCOUNTREQUEST']._serialized_start=1313
  _globals['_REGISTERNAMEDACCOUNTREQUEST']._serialized_end=1395
  _globals['_REGISTERBOTACCOUNTREQUEST']._serialized_start=1397
  _globals['_REGISTERBOTACCOUNTREQUEST']._serialized_end=1477
  _globals['_ADDPARTITIONREQUEST']._serialized_start=1479
  _globals['_ADDPARTITIONREQUEST']._serialized_end=1555
  _globals['_ADMINAUTHINFO']._serialized_start=1557
  _globals['_ADMINAUTHINFO']._serialized_end=1606
  _globals['_SENDPRIVATEMESSAGEREQUEST']._serialized_start=1608
  _globals['_SENDPRIVATEMESSAGEREQUEST']._serialized_end=1705
  _globals['_SENDPUBLICMESSAGEREQUEST']._serialized_start=1707
  _globals['_SENDPUBLICMESSAGEREQUEST']._serialized_end=1805
  _globals['_GETPOSITIONREQUEST']._serialized_start=1807
  _globals['_GETPOSITIONREQUEST']._serialized_end=1896
  _globals['_UPSERTUSERREQUEST']._serialized_start=1898
  _globals['_UPSERTUSERREQUEST']._serialized_end=1967
  _globals['_ADDUSERTOACCOUNTREQUEST']._serialized_start=1969
  _globals['_ADDUSERTOACCOUNTREQUEST']._serialized_end=2061
  _globals['_CLEARUSERACCOUNTSREQUEST']._serialized_start=2063
  _globals['_CLEARUSERACCOUNTSREQUEST']._serialized_end=2139
  _globals['_DELETEUSERFROMACCOUNTREQUEST']._serialized_start=2141
  _globals['_DELETEUSERFROMACCOUNTREQUEST']._serialized_end=2238
  _globals['_ADMINSERVICE']._serialized_start=2241
  _globals['_ADMINSERVICE']._serialized_end=4018
# @@protoc_insertion_point(module_scope)
