# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: exchange.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'exchange.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x65xchange.proto\x12\x08\x65xchange\x1a\x1bgoogle/protobuf/empty.proto\"\xb2\x01\n\x0cOrderRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0f\n\x07logging\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\t\x12\r\n\x05price\x18\x04 \x01(\t\x12!\n\x04side\x18\x05 \x01(\x0e\x32\x13.exchange.OrderSide\x12\x1f\n\x03tif\x18\x06 \x01(\x0e\x32\x12.exchange.OrderTif\x12\x0f\n\x07\x61\x63\x63ount\x18\x07 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x08 \x01(\t\"H\n\x12\x43\x61ncelOrderRequest\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x02 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x03 \x01(\t\"2\n\x0fGenericResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\"J\n\x13\x43\x61ncelOrdersRequest\x12\x11\n\torder_ids\x18\x01 \x03(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x02 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x03 \x01(\t\"v\n\x13GenericResponseList\x12+\n\x08response\x18\x01 \x01(\x0b\x32\x19.exchange.GenericResponse\x12\x32\n\x0forder_responses\x18\x02 \x03(\x0b\x32\x19.exchange.GenericResponse\"7\n\x13GetPositionsRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\"V\n\x08Position\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08position\x18\x02 \x01(\t\x12\x13\n\x0blower_bound\x18\x03 \x01(\t\x12\x13\n\x0bupper_bound\x18\x04 \x01(\t\"7\n\x0ePositionStatus\x12%\n\tpositions\x18\x01 \x03(\x0b\x32\x12.exchange.Position*\x1e\n\tOrderSide\x12\x07\n\x03\x42uy\x10\x00\x12\x08\n\x04Sell\x10\x01*\x1c\n\x08OrderTif\x12\x07\n\x03\x44\x61y\x10\x00\x12\x07\n\x03Ioc\x10\x01\x32\xf3\x02\n\x08\x45xchange\x12@\n\x0bSubmitOrder\x12\x16.exchange.OrderRequest\x1a\x19.exchange.GenericResponse\x12\x46\n\x0b\x43\x61ncelOrder\x12\x1c.exchange.CancelOrderRequest\x1a\x19.exchange.GenericResponse\x12L\n\x0c\x43\x61ncelOrders\x12\x1d.exchange.CancelOrdersRequest\x1a\x1d.exchange.GenericResponseList\x12G\n\x0cGetPositions\x12\x1d.exchange.GetPositionsRequest\x1a\x18.exchange.PositionStatus\x12\x46\n\x11GetExchangeStatus\x12\x16.google.protobuf.Empty\x1a\x19.exchange.GenericResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ORDERSIDE']._serialized_start=762
  _globals['_ORDERSIDE']._serialized_end=792
  _globals['_ORDERTIF']._serialized_start=794
  _globals['_ORDERTIF']._serialized_end=822
  _globals['_ORDERREQUEST']._serialized_start=58
  _globals['_ORDERREQUEST']._serialized_end=236
  _globals['_CANCELORDERREQUEST']._serialized_start=238
  _globals['_CANCELORDERREQUEST']._serialized_end=310
  _globals['_GENERICRESPONSE']._serialized_start=312
  _globals['_GENERICRESPONSE']._serialized_end=362
  _globals['_CANCELORDERSREQUEST']._serialized_start=364
  _globals['_CANCELORDERSREQUEST']._serialized_end=438
  _globals['_GENERICRESPONSELIST']._serialized_start=440
  _globals['_GENERICRESPONSELIST']._serialized_end=558
  _globals['_GETPOSITIONSREQUEST']._serialized_start=560
  _globals['_GETPOSITIONSREQUEST']._serialized_end=615
  _globals['_POSITION']._serialized_start=617
  _globals['_POSITION']._serialized_end=703
  _globals['_POSITIONSTATUS']._serialized_start=705
  _globals['_POSITIONSTATUS']._serialized_end=760
  _globals['_EXCHANGE']._serialized_start=825
  _globals['_EXCHANGE']._serialized_end=1196
# @@protoc_insertion_point(module_scope)
