# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: marketdata.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'marketdata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import exchange_pb2 as exchange__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10marketdata.proto\x12\nmarketdata\x1a\x0e\x65xchange.proto\"M\n\x0bTapeMessage\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\t\x12\x11\n\tissued_at\x18\x04 \x01(\t\"}\n\x0fOrderBookStatus\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12%\n\x04tape\x18\x02 \x03(\x0b\x32\x17.marketdata.TapeMessage\x12#\n\x04\x62ook\x18\x03 \x01(\x0b\x32\x15.marketdata.OrderBook\x12\x0e\n\x06volume\x18\x04 \x01(\t\"]\n\x0bPublicOrder\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\t\x12\r\n\x05price\x18\x03 \x01(\t\x12!\n\x04side\x18\x04 \x01(\x0e\x32\x13.exchange.OrderSide\"Y\n\tOrderBook\x12%\n\x04\x62ids\x18\x01 \x03(\x0b\x32\x17.marketdata.PublicOrder\x12%\n\x04\x61sks\x18\x02 \x03(\x0b\x32\x17.marketdata.PublicOrder\"7\n\x13SubscriptionRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\"\x88\x01\n\x05Order\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x0f\n\x07logging\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\t\x12\r\n\x05price\x18\x05 \x01(\t\x12!\n\x04side\x18\x06 \x01(\x0e\x32\x13.exchange.OrderSide\x12\x12\n\ncreated_at\x18\x07 \x01(\t\"5\n\x10OpenOrdersStatus\x12!\n\x06orders\x18\x01 \x03(\x0b\x32\x11.marketdata.Order\"\x89\x01\n\x04\x46ill\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x10\n\x08order_id\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\r\n\x05price\x18\x04 \x01(\t\x12\x0c\n\x04size\x18\x05 \x01(\t\x12!\n\x04side\x18\x06 \x01(\x0e\x32\x13.exchange.OrderSide\x12\x11\n\tissued_at\x18\x07 \x01(\t\".\n\x0bRecentFills\x12\x1f\n\x05\x66ills\x18\x01 \x03(\x0b\x32\x10.marketdata.Fill\"8\n\x0e\x45xchangeStatus\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x16\n\x0emarket_symbols\x18\x02 \x03(\t\"\xc9\x03\n\nMarketData\x12\x30\n\torderbook\x18\x01 \x01(\x0b\x32\x1b.marketdata.OrderBookStatusH\x00\x12.\n\x06orders\x18\x02 \x01(\x0b\x32\x1c.marketdata.OpenOrdersStatusH\x00\x12-\n\tpositions\x18\x03 \x01(\x0b\x32\x18.exchange.PositionStatusH\x00\x12 \n\x04\x66ill\x18\x04 \x01(\x0b\x32\x10.marketdata.FillH\x00\x12/\n\x0crecent_fills\x18\x05 \x01(\x0b\x32\x17.marketdata.RecentFillsH\x00\x12\x35\n\x0f\x65xchange_status\x18\x06 \x01(\x0b\x32\x1a.marketdata.ExchangeStatusH\x00\x12-\n\x0epublic_message\x18\x07 \x01(\x0b\x32\x13.marketdata.MessageH\x00\x12.\n\x0fprivate_message\x18\x08 \x01(\x0b\x32\x13.marketdata.MessageH\x00\x12\x35\n\x0frecent_messages\x18\t \x01(\x0b\x32\x1a.marketdata.RecentMessagesH\x00\x42\n\n\x08response\";\n\x07Message\x12\x0f\n\x07is_priv\x18\x01 \x01(\x08\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\t\"7\n\x0eRecentMessages\x12%\n\x08messages\x18\x01 \x03(\x0b\x32\x13.marketdata.Message2^\n\x11MarketDataService\x12I\n\x0cStreamStatus\x12\x1f.marketdata.SubscriptionRequest\x1a\x16.marketdata.MarketData0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'marketdata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TAPEMESSAGE']._serialized_start=48
  _globals['_TAPEMESSAGE']._serialized_end=125
  _globals['_ORDERBOOKSTATUS']._serialized_start=127
  _globals['_ORDERBOOKSTATUS']._serialized_end=252
  _globals['_PUBLICORDER']._serialized_start=254
  _globals['_PUBLICORDER']._serialized_end=347
  _globals['_ORDERBOOK']._serialized_start=349
  _globals['_ORDERBOOK']._serialized_end=438
  _globals['_SUBSCRIPTIONREQUEST']._serialized_start=440
  _globals['_SUBSCRIPTIONREQUEST']._serialized_end=495
  _globals['_ORDER']._serialized_start=498
  _globals['_ORDER']._serialized_end=634
  _globals['_OPENORDERSSTATUS']._serialized_start=636
  _globals['_OPENORDERSSTATUS']._serialized_end=689
  _globals['_FILL']._serialized_start=692
  _globals['_FILL']._serialized_end=829
  _globals['_RECENTFILLS']._serialized_start=831
  _globals['_RECENTFILLS']._serialized_end=877
  _globals['_EXCHANGESTATUS']._serialized_start=879
  _globals['_EXCHANGESTATUS']._serialized_end=935
  _globals['_MARKETDATA']._serialized_start=938
  _globals['_MARKETDATA']._serialized_end=1395
  _globals['_MESSAGE']._serialized_start=1397
  _globals['_MESSAGE']._serialized_end=1456
  _globals['_RECENTMESSAGES']._serialized_start=1458
  _globals['_RECENTMESSAGES']._serialized_end=1513
  _globals['_MARKETDATASERVICE']._serialized_start=1515
  _globals['_MARKETDATASERVICE']._serialized_end=1609
# @@protoc_insertion_point(module_scope)
